return {
    {
        'nvim-treesitter/nvim-treesitter',
        config = function()
            local ts_update = require('nvim-treesitter.install').update({ with_sync = true });
            require('nvim-treesitter.configs').setup({
                ensure_installed = { 
                    "lua", "svelte", "javascript", "typescript", "html", "elixir", "vim",
                    "jsdoc", "go",  "css", "scss", "markdown"
                },

                highlight = {
                    enable = true
                }
            })
            vim.treesitter.language.register('markdown', { 'mdx' })
            -- vim.wo.foldmethod = 'expr'
            -- vim.wo.foldexpr = 'v:lua.vim.treesitter.foldexpr()'
        end
    },
    {
        'lewis6991/gitsigns.nvim',
        config = function()
            require('gitsigns').setup{
                on_attach = function(bufnr)
                    local gitsigns = require('gitsigns')

                    local function map(mode, l, r, opts)
                        opts = opts or {}
                        opts.buffer = bufnr
                        vim.keymap.set(mode, l, r, opts)
                    end

                    -- Navigation
                    map('n', ']c', function()
                        if vim.wo.diff then
                            vim.cmd.normal({']c', bang = true})
                        else
                            gitsigns.nav_hunk('next')
                        end
                    end)

                    map('n', '[c', function()
                        if vim.wo.diff then
                            vim.cmd.normal({'[c', bang = true})
                        else
                            gitsigns.nav_hunk('prev')
                        end
                    end)

                    map('n', '<leader>hd', gitsigns.diffthis)
                end
            }
        end
    },
    {
      "folke/snacks.nvim",
      priority = 1000,
      lazy = false,
      opts = {
        -- your configuration comes here
        -- or leave it empty to use the default settings
        -- refer to the configuration section below
        bigfile = { enabled = true },
        notifier = { enabled = true },
        -- quickfile = { enabled = true },
        -- statuscolumn = { enabled = true },
        -- words = { enabled = true },
      },
    },
    {
        "nvim-tree/nvim-tree.lua",
        config = function()
            require("nvim-tree").setup({
                sort = {
                    sorter = "case_sensitive",
                },
                view = {
                    width = 30,
                },
                renderer = {
                    group_empty = true,
                },
                filters = {
                    dotfiles = true,
                },
            })

            local api = require "nvim-tree.api"
            vim.keymap.set('n', '<C-b>', function() api.tree.toggle() end)
        end
    }
    -- { 
    --      'wellle/context.vim',
    -- }
}
